==> haskell-hslua-module-path-1.1.1-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-path
version:              1.1.1
visibility:           public
id:                   hslua-module-path-1.1.1-IDYriUdFa7o9K5yL5w8Njo
key:                  hslua-module-path-1.1.1-IDYriUdFa7o9K5yL5w8Njo
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  c871d4234cbedea1055378d6fd322c2f
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.1-IDYriUdFa7o9K5yL5w8Njo
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.1-HVBwX3UwtOM4TyfwW8Y66n
    hslua-marshalling-2.3.1-JlFD2Zqbo0SOIVYv4AszH
    hslua-packaging-2.3.1-LlGogY58bqTGoGO4RtnF7z text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-path-1.1.1-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-path.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-path
version:              1.1.1
visibility:           public
id:                   hslua-module-path-1.1.1-D01DrBijfI4gD9gwCM2G7
key:                  hslua-module-path-1.1.1-D01DrBijfI4gD9gwCM2G7
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file paths.
description:
    Lua module to work with file paths in a platform
    independent way.

category:             Foreign
abi:                  081290600873b7168531944dc913a53d
exposed:              True
exposed-modules:      HsLua.Module.Path
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-path-1.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-path
hs-libraries:         HShslua-module-path-1.1.1-D01DrBijfI4gD9gwCM2G7
depends:
    base-4.17.2.1 filepath-1.4.2.2
    hslua-core-2.3.1-1dYSTKebqlg8Upiip1Yk54
    hslua-marshalling-2.3.1-LJ93sqJXfX4HF5NTwbyS6t
    hslua-packaging-2.3.1-BnJVahJfYL45D7rypxXVrL text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-path/html/hslua-module-path.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-path/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
